@@ -10,8 +10,6 @@ CRM_OAUTH = {
         "methods": ["POST"],
     }
 }
-
-
 CRM_LICENCA_ENDPOINT = {
     "licencas-list": {
         "resource": "backend/licencas/",
@@ -22,3 +20,15 @@ CRM_LICENCA_ENDPOINT = {
         "methods": ["GET"],
     }
 }
+JOGO_SELF = {
+    "jogos": {
+        "resource": "/jogos-self",
+        "methods": ["GET"],
+    }
+}
+RELATORIOS = {
+    "relatorios": {
+        "resource": "/relatorios",
+        "methods": ["GET", "POST"],
+    }
+}
